#!/bin/bash

XDIALOG_HIGH_DIALOG_COMPAT=1
export XDIALOG_HIGH_DIALOG_COMPAT

[ "`id -u`" != "0" ] && exec sudo "$0" "$@"

TMP="/tmp/mkreadwrite.tmp$$"

bailout(){
rm -f "$TMP"
exit 0
}

trap bailout 1 2 3 15

DIALOG="dialog"
[ -n "$DISPLAY" ] && [ -x /usr/bin/Xdialog ] && DIALOG="Xdialog"

PARTITION="$1"

if [ ! -b "$PARTITION" ]; then
# It's no device file, check if it is a mounted directory instead
PARTITION="$(awk '{if($2=="'"$PARTITION"'"){print $1;exit}}' /proc/mounts)"
fi

case "$LANGUAGE" in
de|ch|at)
TITLE_ERROR="FEHLER"
ERROR1="
Aufruf bitte wie folgt: $0 /dev/partitionsname"
ERROR2="
$PARTITION ist nicht gemountet.
Bitte binden Sie die Partition erst ein, bevor Sie den Lese-/Schreibstatus ndern."
ERROR3="
ACHTUNG: Die Partition $PARTITION ist vom Typ NTFS! Schreiben auf dieses Dateisystem kann zu Datenverlusten fhren, daher sollten Sie Schreiboperationen nur manuell ausfhren und damit rechnen, dass Sie anschlieend das Dateisystem neu formatieren mssen. Dieses Skript wird das nicht riskieren und beendet sich jetzt unverrichteter Dinge."
;;
es)
TITLE_ERROR="ERROR"
ERROR1="
Uso: $0 /dev/partitionname"
ERROR2="
$PARTITION no est montada.
Por favor, monte la particin antes de cambiar su estado de lectura/escritura."
ERROR3="
PRECAUCIN: La particin $PARTITION es de tipo NTFS! Escribir en este tipo de sistema de ficheros puede causar prdida de datos. Por esto, debera realizar slamente operaciones de escritura manualmente y esperar que despus tenga que reinstalar el sistema de ficheros. Este mensaje no har esta operacin tan arriesgada por usted y finalizar sin cambiar nada."
;;
*)
TITLE_ERROR="ERROR"
ERROR1="
Usage: $0 /dev/partitionname"
ERROR2="
$PARTITION is not mounted.
Please mount the partition prior to changing its read/write status."
ERROR3="
WARNING: The partition $PARTITION is of type NTFS! Writing to this filesystem can cause data loss. Because of that, you should only do write operations manually and expect to have to reinstall the filesystem afterwards. This dialog won't do this risky thing for you and will quit now without changing anything."
;;
esac

if [ ! -b "$PARTITION" ]; then
$DIALOG --title "$TITLE_ERROR" --msgbox "$ERROR1" 10 65
bailout 1
fi

FILESYSTEM="$(awk '{if($1=="'"$PARTITION"'"){print $3;exit}}' /proc/mounts)"
STATUS="$(awk '{if($1=="'"$PARTITION"'"){print $4;exit}}' /proc/mounts)"
if [ -z "$FILESYSTEM" -o -z "$STATUS" ]; then
$DIALOG --msgbox "$ERROR2" 10 65
bailout 2
fi

case "$FILESYSTEM" in *ntfs*) $DIALOG --title "$TITLE_ERROR" --msgbox "$ERROR3" 12 65; bailout 3; ;; esac

CHANGETO="ro"
case "$STATUS" in *rw*) STATUS="rw"; ;; *) STATUS="ro"; CHANGETO="rw"; ;; esac

case "$LANGUAGE" in
de|ch|at)
RWMESSAGE="nur-lesbar"
[ "$CHANGETO" = "rw" ] && RWMESSAGE="schreibbar"
TITLE_QUESTION="Partition $PARTITION $RWMESSAGE machen?"
MESSAGE1="
Mchten Sie die Partition $PARTITION ($FILESYSTEM) wirklich $RWMESSAGE machen?"
ERROR4="
Das Remount-Kommando ist fehlgeschlagen. Eventuell greift gerade ein anderes Programm auf das Dateisystem zu."
;;
es)
RWMESSAGE="slo lectura"
[ "$CHANGETO" = "rw" ] && RWMESSAGE="escribible"
TITLE_QUESTION="Crear particin $PARTITION $RWMESSAGE?"
MESSAGE1="
Quiere realmente cambiar la particin $PARTITION ($FILESYSTEM) para ser $RWMESSAGE?"
ERROR4="
El comando remount fall. Puede ser que haya otro proceso accediendo actualmente al sistema de ficheros."
;;
*)
RWMESSAGE="read-only"
[ "$CHANGETO" = "rw" ] && RWMESSAGE="writable"
TITLE_QUESTION="Make partition $PARTITION $RWMESSAGE?"
MESSAGE1="
Do you really want to change partition $PARTITION ($FILESYSTEM) to be $RWMESSAGE?"
ERROR4="
The remount command failed. Maybe there is another process accessing the filesystem currently."
;;
esac

$DIALOG --title "$TITLE_QUESTION" --yesno "$MESSAGE1" 10 65 || bailout 0
mount -o remount,"$CHANGETO" "$PARTITION" >/dev/null 2>&1
if [ "$?" != "0" ]; then
$DIALOG --title "$TITLE_ERROR" --msgbox "$ERROR4" 10 65
bailout 4
fi
bailout 0
